@@ -25,14 +25,16 @@ class CodeScan:
         self,
         tool_gateway: ToolGateway,
         devops_platform_gateway: DevopsPlatformGateway,
+        remote_config_source_gateway: DevopsPlatformGateway,
         git_gateway: GitGateway,
     ):
         self.tool_gateway = tool_gateway
         self.devops_platform_gateway = devops_platform_gateway
+        self.remote_config_source_gateway = remote_config_source_gateway
         self.git_gateway = git_gateway
 
     def set_config_tool(self, dict_args):
-        init_config_tool = self.devops_platform_gateway.get_remote_config(
+        init_config_tool = self.remote_config_source_gateway.get_remote_config(
             dict_args["remote_config_repo"], "engine_sast/engine_code/ConfigTool.json", dict_args["remote_config_branch"]
         )
         scope_pipeline = self.devops_platform_gateway.get_variable("pipeline_name")
@@ -88,7 +90,7 @@ class CodeScan:
 
     def process(self, dict_args, tool):
         config_tool = self.set_config_tool(dict_args)
-        exclusions_data = self.devops_platform_gateway.get_remote_config(
+        exclusions_data = self.remote_config_source_gateway.get_remote_config(
             dict_args["remote_config_repo"], "engine_sast/engine_code/Exclusions.json"
         )
         list_exclusions, skip_tool = self.get_exclusions(tool, exclusions_data)
